/* -*- pftp-c -*- */
#ifndef PFTP_DEFAULT_H
#define PFTP_DEFAULT_H

#ifndef LIBPFTP_API
# ifdef WIN32
#  include "w32-libpftp.h"
# else
#  define LIBPFTP_API 
# endif
#endif

LIBPFTP_API typedef struct pftp_default_s *pftp_default_t;

LIBPFTP_API struct pftp_default_s {
    int pasv;    
    int secure_list, secure_data, use_secure, implicid_ssl;
    int sftp;
    
    uint16_t port_start, port_stop;
    char *bind_to, *myaddr;

    char **prio_list, **ignore_list;
    size_t prio_list_len, ignore_list_len;
};

#endif /* PFTP_DEFAULT_H */
